package com.cweb.controller;

import com.alibaba.fastjson.JSONObject;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.security.SessionObject;
import com.hai.common.security.UserCenter;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.entity.HighOrder;
import com.hai.entity.OutRechargeOrder;
import com.hai.model.HighUserModel;
import com.hai.model.ResponseData;
import com.hai.service.OutRechargeOrderService;
import com.hai.service.TelApiService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

@Controller
@RequestMapping(value = "/outRechargeOrder")
@Api(value = "充值订单接口")
public class OutRechargeOrderController {
    private static Logger log = LoggerFactory.getLogger(HighMerchantStoreController.class);

    @Autowired
    private UserCenter userCenter;

    @Resource
    private OutRechargeOrderService outRechargeOrderService;

    @Resource
    private TelApiService telApiService;

    @RequestMapping(value="/ ",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "增加订单")
    public ResponseData addOrder(@RequestBody OutRechargeOrder outRechargeOrder, HttpServletRequest request) {
        try {

            // 用户
            SessionObject sessionObject = userCenter.getSessionObject(request);
            HighUserModel userInfoModel = (HighUserModel) sessionObject.getObject();

            if (StringUtils.isBlank(outRechargeOrder.getRechargeContent()) ||
                    outRechargeOrder.getPayPrice() == null ||
                    outRechargeOrder.getOrderPrice() == null
            ) {
                log.error("orderToPay error!");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            // 支付类型 1.微信支付
            outRechargeOrder.setPayType(1);
            // 判断充值模式：1 话费充值 2. 中石化 3. 中石油
            if (outRechargeOrder.getRechargeModel() == 1) {
                JSONObject telObject = telApiService.outApiTel(outRechargeOrder.getRechargeContent());
                JSONObject o = telObject.getObject("result",JSONObject.class);
                // 拼接内容
                String remarks = o.get("province").toString() +  o.get("company").toString();
                outRechargeOrder.setRemarks(remarks);
            } else if (outRechargeOrder.getRechargeModel() == 2) {
                // 中石油需要姓名和身份证号
                if (StringUtils.isBlank(outRechargeOrder.getRechargeName()) ||
                        StringUtils.isBlank(outRechargeOrder.getIdCard())
                ) {
                    log.error("orderToPay error!");
                    throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
                }
            }

            return null;



        } catch (Exception e) {
            log.error("HighOrderController -> addOrder() error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }
}
